@@ -4,7 +4,7 @@ from policyengine_canada.model_api import *
 class child_benefit(Variable):
     value_type = float
     entity = Household
-    label = "Canada Child Benefit"
+    label = "Canada child benefit"
     unit = CAD
     documentation = (
         "Non taxable amount paid monthly per children under 18 years of age. "
